@rem This is a script that gathers up information for problem determination.
@rem The files are created and stored in the AEM directory
@rem
@rem The Director logs should also be collected using the getlogs command
@rem
@rem Change log:
@rem 1.1 MRV created
@rem 1.2 MRV Minor fixes and additions
@rem 1.3 MRV Added Dir path and Active checks
@rem 1.4 MRV Added AEM Dir path checks and table stats
@rem 1.5 MRV fixed for 64-bit windows
@rem

@set AEM_MEDIC_VER=1.5

@echo.
@echo AEM Medic %AEM_MEDIC_VER%
@echo.

@setlocal
@set DIR_PATH=x
@rem Find Director paths
@if exist "C:\Program Files\IBM\Director\bin"       @set DIR_PATH="C:\Program Files\IBM\Director"
@if exist "C:\Program Files (x86)\IBM\Director\bin" @set DIR_PATH="C:\Program Files (x86)\IBM\Director"
@if DIR_PATH==x @echo Director commands not available, check installation && exit /b 1

@rem Setup Director paths
@set BIN_DIR=%DIR_PATH%\bin
@set DIR_DIR=%DIR_PATH%
@set LWI_DIR=%DIR_DIR%\lwi
@set AEM_DIR=%DIR_DIR%\ActiveEnergyManager
@set PATH=%BIN_DIR%;%PATH%

@rem Check if Director is Active
@call %BIN_DIR%\smstatus.bat 1>nul 2>&1
@if errorlevel 1 @echo Director is not started. AEM Medic requires that Director is active to collect diagnostic information. && exit /b 2

@rem Check if AEM_DIR is ok
@if NOT EXIST %AEM_DIR% @echo AEM not properly installed. Missing directory %AEM_DIR% && exit /b 2

@rem Setup output file names
@set AEMFILE=aemmedic.txt
@set OUTFILE=%AEM_DIR%\%AEMFILE%

@rem Clear out file
@erase %OUTFILE% 1>nul 2>&1

@echo ===================== Active Energy Manager ======================= >> %OUTFILE%
@echo ======================== AEM Medic %AEM_MEDIC_VER% ============================ >> %OUTFILE%
@echo.
@echo AEM Medic %AEM_MEDIC_VER%
@echo ...collecting service information, please wait...

@echo ============================ DATE and Time ======================== >> %OUTFILE%
@echo Output from date and time: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@date /t >> %OUTFILE%
@time /t >> %OUTFILE%

@echo ============================= ID ================================== >> %OUTFILE%
@echo Output from net user: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@net user >> %OUTFILE% 2>&1

@echo ============================= DIR ================================= >> %OUTFILE%
@echo Output from dir %DIR_DIR%: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@dir %DIR_DIR% /s /q >> %OUTFILE% 2>&1

@echo ============================= NET USE ============================= >> %OUTFILE%
@echo Output from net use:>> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@net use >> %OUTFILE% 2>&1

@echo ============================= NETSTAT ============================= >> %OUTFILE%
@echo Output from netstat: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@netstat -an >> %OUTFILE% 2>&1
@netstat -b  >> %OUTFILE% 2>&1
@netstat -r  >> %OUTFILE% 2>&1

@echo ============================= ARP ================================= >> %OUTFILE%
@echo Output from arp -a: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@arp -a >> %OUTFILE% 2>&1

@echo ============================= IPCONFIG ============================ >> %OUTFILE%
@echo Output from ipconfig /all: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@ipconfig /all >> %OUTFILE% 2>&1

@echo ============================= HOSTS INFO ========================== >> %OUTFILE%
@echo Output from hosts: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@type c:\windows\system\etc\drivers\hosts >> %OUTFILE% 2>&1

@echo ============================ VERSION INFO ========================= >> %OUTFILE%
@echo Output from ver: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@ver >> %OUTFILE% 2>&1

@echo ============================= set SORT ============================ >> %OUTFILE%
@echo Output from set: >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@set >> %OUTFILE% 2>&1

@rem ##########
@rem ##########

@echo ============================= AEM Properties 1 ==================== >> %OUTFILE%
@echo type %AEM_DIR%\AEM.properties >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@type %AEM_DIR%\AEM.properties >> %OUTFILE% 2>&1

@echo ============================= AEM Properties 2 ==================== >> %OUTFILE%
@echo type %LWI_DIR%\conf\overrides\AEM.properties >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@type %LWI_DIR%\conf\overrides\AEM.properties >> %OUTFILE% 2>&1

@echo ============================= AEM Dump Emr All ==================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerinfo --dumpemrall >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerinfo --dumpemrall >> %OUTFILE% 2>&1

@echo ============================= AEM Dump Emr Cache ================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerinfo --dumpemrcache >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerinfo --dumpemrcache >> %OUTFILE% 2>&1

@echo ============================= AEM Dump Poll Queue ================= >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerinfo --dumppollingqueue >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerinfo --dumppollingqueue >> %OUTFILE% 2>&1

@echo ============================= AEM Dump Table Stats ================ >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerinfo --dumptablestats >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerinfo --dumptablestats >> %OUTFILE% 2>&1
@echo ------------------------------------------------------------------- >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerinfo --dumptablesummary >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerinfo --dumptablesummary >> %OUTFILE% 2>&1

@echo ============================= AEM Query HDC ======================= >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerinfo --queryhdc >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerinfo --queryhdc >> %OUTFILE% 2>&1

@echo ============================= AEM lspowerobjects ================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerobjects >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerobjects >> %OUTFILE% 2>&1

@echo ============================= AEM lscollect ======================= >> %OUTFILE%
@echo %BIN_DIR%\smcli lscollect >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lscollect >> %OUTFILE% 2>&1

@echo ============================= AEM lspowerinfo ===================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerinfo >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerinfo >> %OUTFILE% 2>&1

@echo ============================= AEM lspowerlast ===================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lspowerlast >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspowerlast >> %OUTFILE% 2>&1

@echo ============================= AEM lspolicy ======================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lspolicy >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lspolicy >> %OUTFILE% 2>&1

@echo ============================= AEM getpcap ========================= >> %OUTFILE%
@echo %BIN_DIR%\smcli getpcap >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli getpcap >> %OUTFILE% 2>&1

@echo ============================= AEM getpsaver ======================= >> %OUTFILE%
@echo %BIN_DIR%\smcli getpsaver >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli getpsaver >> %OUTFILE% 2>&1

@echo ============================= AEM lsproperties ==================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lsproperties >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lsproperties >> %OUTFILE% 2>&1

@rem ##########
@rem ##########

@echo ============================= Dir version ========================= >> %OUTFILE%
@echo type %DIR_DIR%\version.* >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@type %DIR_DIR%\version.* >> %OUTFILE% 2>&1

@echo ============================= Dir status ========================== >> %OUTFILE%
@echo %BIN_DIR%\smstatus >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@call %BIN_DIR%\smstatus >> %OUTFILE% 2>&1

@echo ============================= LWI Features ======================== >> %OUTFILE%
@echo %LWI_DIR%\bin\lwiupdatemgr -listFeatures >> %OUTFILE% 2>&1
@echo ------------------------------------------------------------------- >> %OUTFILE%
@call %LWI_DIR%\bin\lwiupdatemgr -listFeatures >> %OUTFILE% 2>&1

@echo ============================= LWI ListConfig ====================== >> %OUTFILE%
@echo %LWI_DIR%\bin\lwiupdatemgr -listConfig >> %OUTFILE% 2>&1
@echo ------------------------------------------------------------------- >> %OUTFILE%
@call %LWI_DIR%\bin\lwiupdatemgr -listConfig >> %OUTFILE% 2>&1

@echo ============================= Dir lsbundles ======================= >> %OUTFILE%
@echo %BIN_DIR%\smcli lsbundle >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lsbundle >> %OUTFILE% 2>&1

@echo ============================= Dir lsupd =========================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lsupd >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lsupd >> %OUTFILE% 2>&1

@echo ============================= Dir lssys =========================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lssys -o -T >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lssys -o -T >> %OUTFILE% 2>&1

@echo ============================= Dir lsmeps ========================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lsmeps >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lsmeps >> %OUTFILE% 2>&1

@for %%r in ("PowerUnit" "PowerOutletGroup" "PowerOutlet" "LogicalModule" "SystemChassis" "Chassis" "PowerDomain" "Slot" "LogicalDevice" "PhysicalPackage" "BladeAdminServer" "Fan" "PowerSupply" "Battery" "PowerSource" "Processor" "Card" "LogicalDevice" "Server" "HardwaremanagementConsole" "Group" "GenericNetworkDevice" "PortController" "Sensor" "OperatingSystem" "CoolingDevice" "Rack" "PhysicalFrame" "Location" "Capability" "Service" "ResourceAllocationSettings" "SoftwareInstallation" "RemoteServiceAccessPoint" "IPProtocolEndpoint") do @(

  @echo ============================= Dir lsresources ===================== >> %OUTFILE%
  @echo %BIN_DIR%\smcli lsresources %%r >> %OUTFILE%
  @echo ------------------------------------------------------------------- >> %OUTFILE%
  @%BIN_DIR%\smcli lsresources %%r >> %OUTFILE% 2>&1

  @echo ============================= Dir lsrelationships2 src ============ >> %OUTFILE%
  @echo %BIN_DIR%\smcli lsrelationships2 -src %%r >> %OUTFILE%
  @echo ------------------------------------------------------------------- >> %OUTFILE%
  @%BIN_DIR%\smcli lsrelationships2 -src %%r >> %OUTFILE% 2>&1

  @echo ============================= Dir lsrelationships2 tgt ============ >> %OUTFILE%
  @echo %BIN_DIR%\smcli lsrelationships2 -tgt %%r >> %OUTFILE%
  @echo ------------------------------------------------------------------- >> %OUTFILE%
  @%BIN_DIR%\smcli lsrelationships2 -tgt %%r >> %OUTFILE% 2>&1
)

@echo ============================= Dir lsgp ============================ >> %OUTFILE%
@echo %BIN_DIR%\smcli lsgp -o -l >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lsgp -o -l >> %OUTFILE% 2>&1

@echo ============================= Dir lsuser=========================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lsuser -l >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lsuser -l >> %OUTFILE% 2>&1

@echo ============================= Dir lsusergp ======================== >> %OUTFILE%
@echo %BIN_DIR%\smcli lsusergp -l >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli lsusergp -l >> %OUTFILE% 2>&1

@echo ============================= Dir event/listevents ================ >> %OUTFILE%
@echo %BIN_DIR%\smcli events/listevents -r >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@%BIN_DIR%\smcli event/listevents -r >> %OUTFILE% 2>&1

@echo ============================= LWI Status ========================== >> %OUTFILE%
@echo %LWI_DIR%\bin\lwistatus >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@call %LWI_DIR%\bin\lwistatus >> %OUTFILE% 2>&1

@echo ============================= LWI Plugin Status==================== >> %OUTFILE%
@echo %LWI_DIR%\bin\lwiplugin -status >> %OUTFILE%
@echo ------------------------------------------------------------------- >> %OUTFILE%
@call %LWI_DIR%\bin\lwiplugin -status >> %OUTFILE% 2>&1

@echo ------------------------------------------------------------------- >> %OUTFILE%
@echo ----------------------------END------------------------------------ >> %OUTFILE%

@echo.
@echo AEM Medic has produced the following file: %OUTFILE%
@echo If requested, please send this file to IBM Service for analysis.
@echo.
@echo.
